@@ -1,7 +1,7 @@
 use crate::states;
 
 /// The state of a group.
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone, Copy)]
 pub struct GroupStatus {
     pub power_state: states::GroupPowerState,
     /// Valid values are `0`-`15`.
